Annotation Type Parent


@Retention(RUNTIME)
@Target(FIELD)
public @interface Parent

When placed on an entity field of type Key, the key will be used as the parent ancestor for entity grouping.

This annotation can only be placed on a single Key field within each entity.

Author:
Jeff Schnitzer