Package com.googlecode.objectify.cache
Interface MemcacheStats
-
- All Known Implementing Classes:
EntityMemcacheStats
public interface MemcacheStatsInterface for tracking hit rates of the entity memcache.- Author:
- Jeff Schnitzer
-
-
Method Summary
All Methods Instance Methods Abstract Methods Modifier and Type Method Description voidrecordHit(com.google.appengine.api.datastore.Key key)voidrecordMiss(com.google.appengine.api.datastore.Key key)
-