Class TriggerSuccessFuture<T>
java.lang.Object
com.googlecode.objectify.cache.TriggerFuture<T>
com.googlecode.objectify.cache.TriggerSuccessFuture<T>
- All Implemented Interfaces:
Future<T>
Extends TriggerFuture so that it only gets triggered on successful (no exception) completion of the Future. This prevents, for example, cache put()s from firing when concurrency exceptions are thrown.
- Author:
- Jeff Schnitzer invalid input: '<'[email protected]>
-
Nested Class Summary
Nested classes/interfaces inherited from interface Future
Future.State -
Field Summary
Fields inherited from class TriggerFuture
raw -
Constructor Summary
ConstructorsConstructorDescriptionTriggerSuccessFuture(Future<T> raw) Wrap a normal Futureinvalid input: '<'?> -
Method Summary
Methods inherited from class TriggerFuture
cancel, get, get, isCancelled, isDoneMethods inherited from class Object
clone, equals, finalize, getClass, hashCode, notify, notifyAll, toString, wait, wait, waitMethods inherited from interface Future
exceptionNow, resultNow, state
-
Constructor Details
-
TriggerSuccessFuture
-
-
Method Details
-
success
This method will be called ONCE upon successful completion of the future. -
trigger
protected final void trigger()Description copied from class:TriggerFutureThis method will be called ONCE upon completion of the future, successful or not. Beware that this.get() may throw an exception.- Specified by:
triggerin classTriggerFuture<T>
-