Package com.googlecode.objectify.cache.spymemcached
-
Class Summary Class Description SpyIdentifiableValue SpyMemcacheService Among the issues this impl needs to be concerned with is that memcached doesn't store nulls.
| Class | Description |
|---|---|
| SpyIdentifiableValue | |
| SpyMemcacheService |
Among the issues this impl needs to be concerned with is that memcached doesn't store nulls.
|