Class IfNotDefault
- All Implemented Interfaces:
If<Object,Object>,InitializeIf
public class IfNotDefault extends ValueIf<Object> implements InitializeIf
The opposite of IfDefault
- Author:
- Jeff Schnitzer
-
Constructor Summary
Constructors -
Method Summary
Modifier and TypeMethodDescriptionvoidinit(ObjectifyFactory fact, Field field)Instructs the condition instance which field it lives on.booleanmatchesValue(Object value)Test a simple property value.Methods inherited from class com.googlecode.objectify.condition.ValueIf
matchesPojo
-
Constructor Details
-
IfNotDefault
public IfNotDefault()
-
-
Method Details
-
init
Description copied from interface:InitializeIfInstructs the condition instance which field it lives on.- Specified by:
initin interfaceInitializeIf- Parameters:
fact- is just handy to have aroundfield- is the field which has the annotation with this condition.
-
matchesValue
Description copied from interface:IfTest a simple property value.- Specified by:
matchesValuein interfaceIf<Object,Object>- Parameters:
value- is the actual value of a particular field- Returns:
- true if the value matches the condition defined by an instance of this interface.
-