Uses of Interface
com.googlecode.objectify.condition.InitializeIf
-
Packages that use InitializeIf Package Description com.googlecode.objectify.condition -
-
Uses of InitializeIf in com.googlecode.objectify.condition
Classes in com.googlecode.objectify.condition that implement InitializeIf Modifier and Type Class Description classIfDefaultThis condition tests against the default value of the field that it is placed upon, whatever that default may be.classIfNotDefaultThe opposite of IfDefault
-