Package com.googlecode.objectify.util
Class ResultTranslator<F,T>
- java.lang.Object
-
- com.googlecode.objectify.util.ResultCache<T>
-
- com.googlecode.objectify.util.ResultTranslator<F,T>
-
- All Implemented Interfaces:
Result<T>,Serializable
- Direct Known Subclasses:
MakeListResult,ResultWrapper
public abstract class ResultTranslator<F,T> extends ResultCache<T>
Translates from one arbitrary thing to a Result of another arbitrary thing, caching the value.- Author:
- Jeff Schnitzer
- See Also:
- Serialized Form
-
-
Constructor Summary
Constructors Constructor Description ResultTranslator(F from)
-
Method Summary
All Methods Instance Methods Abstract Methods Concrete Methods Modifier and Type Method Description TnowUncached()StringtoString()We can get away with this because the subclass almost always provides concrete typesprotected abstract Ttranslate(F from)-
Methods inherited from class com.googlecode.objectify.util.ResultCache
isExecuted, now, postExecuteHook, writeReplace
-
-
-
-
Constructor Detail
-
ResultTranslator
public ResultTranslator(F from)
-
-
Method Detail
-
nowUncached
public T nowUncached()
- Specified by:
nowUncachedin classResultCache<T>
-
toString
public String toString()
We can get away with this because the subclass almost always provides concrete types- Overrides:
toStringin classResultCache<T>
-
-