Constant Field Values
Contents
com.googlecode.*
-
com.googlecode.objectify.ObjectifyFactory Modifier and Type Constant Field Value public static final StringMEMCACHE_NAMESPACE"ObjectifyCache"
-
com.googlecode.objectify.cache.EntityMemcache Modifier and Type Constant Field Value public static final StringNEGATIVE"NEGATIVE"
-
com.googlecode.objectify.impl.translate.ClassTranslator<P> Modifier and Type Constant Field Value public static final StringDISCRIMINATOR_INDEX_PROPERTY"^i"public static final StringDISCRIMINATOR_PROPERTY"^d"
-
com.googlecode.objectify.impl.translate.opt.BigDecimalLongTranslatorFactory Modifier and Type Constant Field Value public static final longDEFAULT_FACTOR1000L